@@ -16,7 +16,6 @@
 """
 Test cases for the symmetric key class.
 """
-
 from castellan.common.objects import symmetric_key as sym_key
 from castellan.tests import base
 
@@ -27,16 +26,29 @@ class SymmetricKeyTestCase(base.KeyTestCase):
         return sym_key.SymmetricKey(self.algorithm,
                                     self.bit_length,
                                     self.encoded,
-                                    self.name)
+                                    self.name,
+                                    self.created)
 
     def setUp(self):
         self.algorithm = 'AES'
         self.encoded = bytes(b'0' * 64)
         self.bit_length = len(self.encoded) * 8
         self.name = 'my key'
+        self.created = 1448088699
 
         super(SymmetricKeyTestCase, self).setUp()
 
+    def test_is_not_only_metadata(self):
+        self.assertFalse(self.key.is_metadata_only())
+
+    def test_is_only_metadata(self):
+        k = sym_key.SymmetricKey(self.algorithm,
+                                 self.bit_length,
+                                 None,
+                                 self.name,
+                                 self.created)
+        self.assertTrue(k.is_metadata_only())
+
     def test_get_format(self):
         self.assertEqual('RAW', self.key.format)
 
@@ -52,23 +64,35 @@ class SymmetricKeyTestCase(base.KeyTestCase):
     def test_get_bit_length(self):
         self.assertEqual(self.bit_length, self.key.bit_length)
 
+    def test_get_created(self):
+        self.assertEqual(self.created, self.key.created)
+
+    def test_get_created_none(self):
+        created = None
+        key = sym_key.SymmetricKey(self.algorithm,
+                                   self.bit_length,
+                                   self.encoded,
+                                   self.name,
+                                   created)
+
+        self.assertEqual(created, key.created)
+
     def test___eq__(self):
         self.assertTrue(self.key == self.key)
         self.assertTrue(self.key is self.key)
 
         self.assertFalse(self.key is None)
-        self.assertFalse(None == self.key)
+        self.assertFalse(None == self.key)  # noqa: E711
 
         other_key = sym_key.SymmetricKey(self.algorithm,
                                          self.bit_length,
-                                         self.encoded,
-                                         self.name)
+                                         self.encoded)
         self.assertTrue(self.key == other_key)
         self.assertFalse(self.key is other_key)
 
     def test___ne___none(self):
         self.assertTrue(self.key is not None)
-        self.assertTrue(None != self.key)
+        self.assertTrue(None != self.key)  # noqa: E711
 
     def test___ne___algorithm(self):
         other_key = sym_key.SymmetricKey('DES',
@@ -77,7 +101,7 @@ class SymmetricKeyTestCase(base.KeyTestCase):
                                          self.name)
         self.assertTrue(self.key != other_key)
 
-    def test___ne___length(self):
+    def test___ne___bit_length(self):
         other_key = sym_key.SymmetricKey(self.algorithm,
                                          self.bit_length * 2,
                                          self.encoded,
@@ -91,10 +115,3 @@ class SymmetricKeyTestCase(base.KeyTestCase):
                                          different_encoded,
                                          self.name)
         self.assertTrue(self.key != other_key)
-
-    def test___ne___name(self):
-        other_key = sym_key.SymmetricKey(self.algorithm,
-                                         self.bit_length,
-                                         self.encoded,
-                                         'other key')
-        self.assertTrue(self.key != other_key)
